@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v1.4.4';
+our $VERSION = 'v1.4.5';
 
 # update DEPENDENCIES in POD & Build.PL & README
 use Perl6::Export::Attrs;
@@ -69,6 +69,8 @@ sub set_config :Export {
 1; # Magic true value required at end of module
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Narada::Config - manage project configuration
@@ -76,7 +78,7 @@ Narada::Config - manage project configuration
 
 =head1 VERSION
 
-This document describes Narada::Config version v1.4.4
+This document describes Narada::Config version v1.4.5
 
 
 =head1 SYNOPSIS
@@ -112,7 +114,6 @@ It must not contain "./" or "../".
 
 Return: contents of file 'config/VARIABLE_NAME' as scalar.
 
-
 =item B<get_config_line>( VARIABLE_NAME )
 
 Suitable for reading files which contain single string (with/without \n at end).
@@ -123,7 +124,6 @@ It must not contain "./" or "../".
 Return: contents of file 'config/VARIABLE_NAME' as scalar without last \n
 (if any). Raise exception if file contain more than one line.
 
-
 =item B<get_db_config>()
 
 Helper for reading database configuration from C<config/db/*>.
@@ -138,7 +138,6 @@ Return: nothing if database not configured, or hashref with keys:
     {dsn_nodb}  'dbi:mysql:;host=$host;port=$port'
     {dsn}       'dbi:mysql:;host=$host;port=$port;database=$db'
 
-
 =item B<set_config>( VARIABLE_NAME, VARIABLE_VALUE )
 
 See limitation for VARIABLE_VALUE above.
@@ -149,7 +148,6 @@ parent directories if needed).
 
 Return: nothing.
 
-
 =back
 
 
@@ -161,12 +159,10 @@ Return: nothing.
 
 Thrown by set_config() and get_config() on wrong VARIABLE_NAME.
 
-
 =item C<< no such config: %s >>
 
 Thrown by get_config() if file 'config/VARIABLE_NAME' doesn't exist.
 
-
 =item C<< open(config/%s): %s >>
 
 =item C<< close: %s >>
@@ -175,7 +171,6 @@ Thrown by get_config() if file 'config/VARIABLE_NAME' doesn't exist.
 
 Internal errors.
 
-
 =back
 
 
@@ -185,31 +180,57 @@ Narada::Config requires configuration files and directories provided by
 Narada framework.
 
 
-=head1 DEPENDENCIES
+=head1 SUPPORT
 
- Perl6::Export::Attrs
+=head2 Bugs / Feature Requests
 
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/powerman/Narada/issues>.
+You will be notified automatically of any progress on your issue.
 
-=head1 INCOMPATIBILITIES
+=head2 Source Code
 
-None reported.
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+Feel free to fork the repository and submit pull requests.
 
+L<https://github.com/powerman/Narada>
 
-=head1 BUGS AND LIMITATIONS
+    git clone https://github.com/powerman/Narada.git
 
-No bugs have been reported.
+=head2 Resources
 
-Please report any bugs or feature requests to
-C<bug-narada@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+=over
+
+=item * MetaCPAN Search
+
+L<https://metacpan.org/search?q=Narada>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/dist/Narada>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Narada>
+
+=item * CPAN Testers Matrix
+
+L<http://matrix.cpantesters.org/?dist=Narada>
+
+=item * CPANTS: A CPAN Testing Service (Kwalitee)
+
+L<http://cpants.cpanauthors.org/dist/Narada>
+
+=back
 
 
 =head1 AUTHOR
 
-Alex Efros  C<< <powerman@cpan.org> >>
+Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2008-2015 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
@@ -218,25 +239,4 @@ This is free software, licensed under:
   The MIT (X11) License
 
 
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
\ No newline at end of file
+=cut
\ No newline at end of file
