@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = 'v1.4.4';
+our $VERSION = 'v1.4.5';
 
 # update DEPENDENCIES in POD & Build.PL & README
 use Time::HiRes qw( sleep );
@@ -73,6 +73,8 @@ sub child_inherit_lock :Export {
 1; # Magic true value required at end of module
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Narada::Lock - manage project locks
@@ -80,7 +82,7 @@ Narada::Lock - manage project locks
 
 =head1 VERSION
 
-This document describes Narada::Lock version v1.4.4
+This document describes Narada::Lock version v1.4.5
 
 
 =head1 SYNOPSIS
@@ -160,7 +162,6 @@ Use unlock() to free this lock.
 
 Return: true if able to get lock.
 
-
 =item B<exclusive_lock>()
 
 Try to get exclusive lock which is required to guarantee consistent project
@@ -177,7 +178,6 @@ Use unlock_new() in combination with exit() or unlock() to free these locks.
 
 Return: nothing.
 
-
 =item B<unlock_new>()
 
 Free first lock set by exclusive_lock() (i.e. remove file 'var/.lock.new').
@@ -186,14 +186,12 @@ call unlock().
 
 Return: nothing.
 
-
 =item B<unlock>()
 
 Free lock set by shared_lock() (or second lock set by exclusive_lock()).
 
 Return: nothing.
 
-
 =item B<child_inherit_lock>( $is_inherit )
 
 By default, child processes don't inherit our FD with lock.
@@ -225,7 +223,6 @@ Examples:
 
 Return: nothing.
 
-
 =back
 
 
@@ -244,7 +241,6 @@ Return: nothing.
 Probably directory 'var/' or files 'var/.lock' and 'var/.lock.new' doesn't
 exists or has wrong permissions.
 
-
 =back
 
 
@@ -258,31 +254,57 @@ exclusive_lock(), unlock_new(), unlock() and child_inherit_lock() will do
 nothing (shared_lock() will return true).
 
 
-=head1 DEPENDENCIES
+=head1 SUPPORT
 
- Perl6::Export::Attrs
+=head2 Bugs / Feature Requests
 
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/powerman/Narada/issues>.
+You will be notified automatically of any progress on your issue.
 
-=head1 INCOMPATIBILITIES
+=head2 Source Code
 
-None reported.
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+Feel free to fork the repository and submit pull requests.
 
+L<https://github.com/powerman/Narada>
 
-=head1 BUGS AND LIMITATIONS
+    git clone https://github.com/powerman/Narada.git
 
-No bugs have been reported.
+=head2 Resources
 
-Please report any bugs or feature requests to
-C<bug-narada@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.
+=over
+
+=item * MetaCPAN Search
+
+L<https://metacpan.org/search?q=Narada>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/dist/Narada>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Narada>
+
+=item * CPAN Testers Matrix
+
+L<http://matrix.cpantesters.org/?dist=Narada>
+
+=item * CPANTS: A CPAN Testing Service (Kwalitee)
+
+L<http://cpants.cpanauthors.org/dist/Narada>
+
+=back
 
 
 =head1 AUTHOR
 
-Alex Efros  C<< <powerman@cpan.org> >>
+Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2008-2015 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
@@ -291,25 +313,4 @@ This is free software, licensed under:
   The MIT (X11) License
 
 
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
\ No newline at end of file
+=cut
\ No newline at end of file
